@@ -55,7 +55,7 @@ system("rm -rf qgvtp*");
 
 $cmd = "svn export $repo $basedir";
 system($cmd);
-system("cp $basedir/icons/qgv64.png $basedir/src/qgvdial.png");
+system("cp $basedir/icons/qgv.png $basedir/src/qgvdial.png");
 
 # Append the version to the pro file
 open(PRO_FILE, ">>$basedir/src/src.pro") || die "Cannot open pro file";
@@ -87,7 +87,7 @@ system("mv $basedir/build-files/qgvdial.Text.service.maemo $basedir/build-files/
 system("mv $basedir/build-files/qgvdial.desktop.maemo $basedir/build-files/qgvdial.desktop");
 
 # Fix the changelog and put it into the correct location
-system("head -1 $basedir/debian/changelog >dest.txt && cat $basedir/build-files/changelog.qgvdial >>dest.txt && tail -2 $basedir/debian/changelog | head -1 | sed 's/unknown/Yuvraaj Kelkar/g' >>dest.txt && mv dest.txt $basedir/debian/changelog");
+system("head -1 $basedir/debian/changelog >dest.txt && cat $basedir/build-files/changelog.qgvdial >>dest.txt && tail -2 $basedir/debian/changelog | sed 's/unknown/Yuvraaj Kelkar/g' >>dest.txt && mv dest.txt $basedir/debian/changelog");
 
 # Make sure all make files are present before mucking with them.
 system("cd $basedir && make src/Makefile");
